package moderation

import (
	"context"
	"fmt"
	"net/http"

	"github.com/google/go-querystring/query"
	"go.fifitido.net/twitch/api/endpoint"
)

type AddChannelVIPParams struct {
	// The ID of the user to give VIP status to.
	UserID string `url:"user_id"`

	// The ID of the broadcaster that’s adding the user as a VIP. This ID must match the user ID in the access token.
	BroadcasterID string `url:"broadcaster_id"`
}

// Adds the specified user as a VIP in the broadcaster’s channel.
//
// Rate Limits: The broadcaster may add a maximum of 10 VIPs within a 10-second window.
//
// Requires a user access token that includes the channel:manage:vips scope.
func (m *Moderation) AddChannelVIP(ctx context.Context, params *AddChannelVIPParams) error {
	v, _ := query.Values(params)

	req, err := http.NewRequestWithContext(ctx, http.MethodPost, endpoint.Make(m.baseUrl, "channels/vips", v), nil)
	if err != nil {
		return err
	}

	res, err := m.client.Do(req)
	if err != nil {
		return err
	}
	defer res.Body.Close()

	statusOK := res.StatusCode >= 200 && res.StatusCode < 300
	if !statusOK {
		return fmt.Errorf("failed to add channel VIP (%d)", res.StatusCode)
	}

	return nil
}
