package auth

type Scope string

func (s Scope) String() string {
	return string(s)
}

// Twitch API scopes
const (
	// View analytics data for the Twitch Extensions owned by the authenticated account.
	ScopeAnalyticsReadExtensions Scope = "analytics:read:extensions"

	// View analytics data for the games owned by the authenticated account.
	ScopeAnalyticsReadGames Scope = "analytics:read:games"

	// View Bits information for a channel.
	ScopeBitsRead Scope = "bits:read"

	// Manage ads schedule for a channel.
	ScopeChannelManageAds Scope = "channel:manage:ads"

	// Read the ads schedule and details on your channel.
	ScopeChannelReadAds Scope = "channel:read:ads"

	// Manage a channel’s broadcast configuration, including updating channel configuration and managing stream markers and stream tags.
	ScopeChannelManageBroadcast Scope = "channel:manage:broadcast"

	// Read charity campaign details and user donations on your channel.
	ScopeChannelReadCharity Scope = "channel:read:charity"

	// Run commercials on a channel.
	ScopeChannelEditCommercial Scope = "channel:edit:commercial"

	// View a list of users with the editor role for a channel.
	ScopeChannelReadEditors Scope = "channel:read:editors"

	// Manage a channel’s Extension configuration, including activating Extensions.
	ScopeChannelManageExtensions Scope = "channel:manage:extensions"

	// View Creator Goals for a channel.
	ScopeChannelReadGoals Scope = "channel:read:goals"

	// Read Guest Star details for your channel.
	ScopeChannelReadGuestStar Scope = "channel:read:guest_star"

	// Manage Guest Star for your channel.
	ScopeChannelManageGuestStar Scope = "channel:manage:guest_star"

	// View Hype Train information for a channel.
	ScopeChannelReadHypeTrain Scope = "channel:read:hype_train"

	// Add or remove the moderator role from users in your channel.
	ScopeChannelManageModerators Scope = "channel:manage:moderators"

	// View a channel’s polls.
	ScopeChannelReadPolls Scope = "channel:read:polls"

	// Manage a channel’s polls.
	ScopeChannelManagePolls Scope = "channel:manage:polls"

	// View a channel's Channel Points Predictions.
	ScopeChannelReadPredictions Scope = "channel:read:predictions"

	// Manage a channel's Channel Points Predictions.
	ScopeChannelManagePredictions Scope = "channel:manage:predictions"

	// Manage a channel raiding another channel.
	ScopeChannelManageRaid Scope = "channel:manage:raids"

	// View Channel Points custom rewards and their redemptions on a channel.
	ScopeChannelReadRedemptions Scope = "channel:read:redemptions"

	// Manage Channel Points custom rewards on a channel.
	ScopeChannelManageRedemptions Scope = "channel:manage:redemptions"

	// Manage a channel's stream schedule.
	ScopeChannelManageSchedule Scope = "channel:manage:schedule"

	// View an authorized user's stream key.
	ScopeChannelReadStreamKey Scope = "channel:read:stream_key"

	// View a list of all subscribers to a channel and check if a user is subscribed to a channel.
	ScopeChannelReadSubscriptions Scope = "channel:read:subscriptions"

	// Manage a channel’s videos, including deleting videos.
	ScopeChannelManagerVideos Scope = "channel:manage:videos"

	// Read the list of VIPs in your channel.
	ScopeChannelReadVips Scope = "channel:read:vips"

	// Add or remove the VIP role from users in your channel.
	ScopeChannelManageVips Scope = "channel:manage:vips"

	// Manage Clips for a channel.
	ScopeClipsEdit Scope = "clips:edit"

	// View a channel’s moderation data including Moderators, Bans, Timeouts, and Automod settings.
	ScopeModerationRead Scope = "moderation:read"

	// Send announcements in channels where you have the moderator role.
	ScopeModerationManageAnnouncements Scope = "moderation:manage:announcements"

	// Manage messages held for review by AutoMod in channels where you are a moderator.
	ScopeModerationManageAutoMod Scope = "moderation:manage:automod"

	// View a broadcaster’s AutoMod settings.
	ScopeModerationReadAutoModSettings Scope = "moderation:read:automod_settings"

	// Manage a broadcaster’s AutoMod settings.
	ScopeModerationManageAutoModSettings Scope = "moderation:manage:automod_settings"

	// Ban and unban users.
	ScopeModeratorManagerBannedUsers Scope = "moderator:manage:banned_users"

	// View a broadcaster’s list of blocked terms.
	ScopeModeratorReadBlockedTerms Scope = "moderator:read:blocked_terms"

	// Manage a broadcaster’s list of blocked terms.
	ScopeModeratorManageBlockedTerms Scope = "moderator:manage:blocked_terms"

	// Delete chat messages in channels where you have the moderator role
	ScopeModerationManageChatMessages Scope = "moderation:manage:chat_messages"

	// View a broadcaster’s chat room settings.
	ScopeModerationReadChatSettings Scope = "moderation:read:chat_settings"

	// Manage a broadcaster’s chat room settings.
	ScopeModerationManageChatSettings Scope = "moderation:manage:chat_settings"

	// View the chatters in a broadcaster’s chat room.
	ScopeModerationReadChatters Scope = "moderation:read:chatters"

	// Read the followers of a broadcaster.
	ScopeModerationReadFollowers Scope = "moderation:read:followers"

	// Read Guest Star details for channels where you are a Guest Star moderator.
	ScopeModerationReadGuestStars Scope = "moderation:read:guest_stars"

	// Manage Guest Star for channels where you are a Guest Star moderator.
	ScopeModerationManageGuestStars Scope = "moderation:manage:guest_stars"

	// View a broadcaster’s Shield Mode status.
	ScopeModerationReadShieldMode Scope = "moderation:read:shield_mode"

	// Manage a broadcaster’s Shield Mode status.
	ScopeModerationManageShieldMode Scope = "moderation:manage:shield_mode"

	// View a broadcaster’s shoutouts.
	ScopeModerationReadShoutouts Scope = "moderation:read:shoutouts"

	// Manage a broadcaster’s shoutouts.
	ScopeModerationManageShoutouts Scope = "moderation:manage:shoutouts"

	// Manage a user object.
	ScopeUserEdit Scope = "user:edit"

	// View the block list of a user.
	ScopeUserReadBlockedUsers Scope = "user:read:blocked_users"

	// Manage the block list of a user.
	ScopeUserManageBlockedUsers Scope = "user:manage:blocked_users"

	// View a user’s broadcasting configuration, including Extension configurations.
	ScopeUserReadBroadcast Scope = "user:read:broadcast"

	// Update the color used for the user’s name in chat.
	ScopeUserEditChatColor Scope = "user:edit:chat_color"

	// View a user’s email address.
	ScopeUserReadEmail Scope = "user:read:email"

	// View the list of channels a user follows.
	ScopeUserReadFollows Scope = "user:read:follows"

	// Read the list of channels you have moderator privileges in.
	ScopeUserReadModeratedChannels = "user:read:moderated_channels"

	// View if an authorized user is subscribed to specific channels.
	ScopeUserReadSubscriptions = "user:read:subscriptions"

	// Read whispers that you send and receive, and send whispers on your behalf.
	ScopeUserManageWhispers = "user:manage:whispers"
)

// Chat and PubSub scopes
const (
	// Allows the client’s bot users access to a channel.
	ScopeChannelBot Scope = "channel:bot"

	// Perform moderation actions in a channel. The user requesting the scope must be a moderator in the channel.
	ScopeChannelModerate Scope = "channel:moderate"

	// Send live stream chat messages using an IRC connection.
	ScopeChatEdit Scope = "chat:edit"

	// View live stream chat messages using an IRC connection.
	ScopeChatRead Scope = "chat:read"

	// Allow client’s bot to act as this user.
	ScopeUserBot Scope = "user:bot"

	// View live stream chat and room messages using EventSub.
	ScopeUserReadChat Scope = "user:read:chat"

	// Send live stream chat messages using Send Chat Message API.
	ScopeUserWriteChat Scope = "user:write:chat"

	// View your whisper messages.
	ScopeWhispersRead Scope = "whispers:read"

	// Send whisper messages.
	ScopeWhispersEdit Scope = "whispers:edit"
)
